#!/usr/bin/env bash
rm -f irgsh-go/
rm -f irgsh-go/etc/
rm -f irgsh-go/etc/irgsh/
rm -f irgsh-go/etc/irgsh/config.yaml
rm -f irgsh-go/etc/init.d/
rm -f irgsh-go/etc/init.d/irgsh-builder
rm -f irgsh-go/etc/init.d/irgsh-chief
rm -f irgsh-go/etc/init.d/irgsh-repo
rm -f irgsh-go/usr/
rm -f irgsh-go/usr/share/
rm -f irgsh-go/usr/share/irgsh/
rm -f irgsh-go/usr/share/irgsh/reprepro-template/
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/blacklist.pkg
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/tiffany.py
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/changelogs.sh
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/distributions.orig
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/options.orig
rm -f irgsh-go/usr/share/irgsh/reprepro-template/conf/updates.orig
rm -f irgsh-go/usr/bin/
rm -f irgsh-go/usr/bin/irgsh-cli
rm -f irgsh-go/usr/bin/irgsh-builder
rm -f irgsh-go/usr/bin/irgsh-chief
rm -f irgsh-go/usr/bin/irgsh-repo
